atproto_sdl/pipeline

The actual parse pipeline (lex, parse, lower), factored out of the top-level atproto_sdl module so that atproto_sdl/cli can call it without importing atproto_sdl itself, which would form an import cycle with atproto_sdl.main calling into atproto_sdl/cli.

Values

pub fn parse(
  source: String,
  id: String,
) -> Result(ast.LexiconDoc, error.ParseError)
pub fn parse_in_tree(
  source: String,
  id: String,
  known_docs: set.Set(String),
) -> Result(ast.LexiconDoc, error.ParseError)

Parse with workspace knowledge: known_docs are the NSIDs of the other documents compiled in the same tree, used to disambiguate dotted reference paths (see lower.lower_in_tree).

Search Document